@@ -338,9 +338,21 @@ void procman_lsof(ProcData *procdata)
     GtkWidget *entry = gtk_entry_new();
 
     gtk_box_pack_start(GTK_BOX(hbox), entry, TRUE, TRUE, 0);
-    GtkWidget *search_button = gtk_button_new_from_stock(GTK_STOCK_FIND);
+
+    GtkWidget *search_button = GTK_WIDGET (g_object_new (GTK_TYPE_BUTTON,
+                                                         "label", "gtk-find",
+                                                         "use-stock", TRUE,
+                                                         "use-underline", TRUE,
+                                                         NULL));
+
     gtk_box_pack_start(GTK_BOX(hbox), search_button, FALSE, FALSE, 0);
-    GtkWidget *clear_button = gtk_button_new_from_stock(GTK_STOCK_CLEAR);
+
+    GtkWidget *clear_button = GTK_WIDGET (g_object_new (GTK_TYPE_BUTTON,
+                                                        "label", "gtk-clear",
+                                                        "use-stock", TRUE,
+                                                        "use-underline", TRUE,
+                                                        NULL));
+
     /* The default accelerator collides with the default close accelerator. */
     gtk_button_set_label(GTK_BUTTON(clear_button), _("C_lear"));
     gtk_box_pack_start(GTK_BOX(hbox), clear_button, FALSE, FALSE, 0);
@@ -370,7 +382,13 @@ void procman_lsof(ProcData *procdata)
     gtk_box_pack_start(GTK_BOX(mainbox), scrolled, TRUE, TRUE, 0);
 
     GtkWidget *bottom_box = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 12);
-    GtkWidget *close_button = gtk_button_new_from_stock(GTK_STOCK_CLOSE);
+
+    GtkWidget *close_button = GTK_WIDGET (g_object_new (GTK_TYPE_BUTTON,
+                                                        "label", "gtk-close",
+                                                        "use-stock", TRUE,
+                                                        "use-underline", TRUE,
+                                                        NULL));
+
     gtk_box_pack_start(GTK_BOX(mainbox), bottom_box, FALSE, FALSE, 0);
     gtk_box_pack_end(GTK_BOX(bottom_box), close_button, FALSE, FALSE, 0);
 
